<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk" sourcelanguage="en">
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Вибрати мову програми:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Системна мова&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Примітка</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Перезапустіть програму, щоб нова мова вступила в дію.</translation>
    </message>
</context>
<context>
    <name>Report</name>
    <message>
        <source>Time Sheet Report</source>
        <translation>Облік робочого часу</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Ім&apos;я:</translation>
    </message>
    <message>
        <source>Company:</source>
        <translation>Компанія:</translation>
    </message>
    <message>
        <source>Address:</source>
        <translation>Адреса:</translation>
    </message>
    <message>
        <source>Phone:</source>
        <translation>Телефон:</translation>
    </message>
    <message>
        <source>Fax:</source>
        <translation>Факс:</translation>
    </message>
    <message>
        <source>Email:</source>
        <translation>Електронна пошта:</translation>
    </message>
    <message>
        <source>Website:</source>
        <translation>Веб-сайт:</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>Не доступно</translation>
    </message>
    <message>
        <source>Prepend currency symbol</source>
        <translation>Додавати символ валюти</translation>
    </message>
    <message>
        <source>Hourly rate:</source>
        <translation>Погодинна оплата:</translation>
    </message>
    <message>
        <source>Tax rate:</source>
        <translation>Податкова ставка:</translation>
    </message>
    <message>
        <source>Currency symbol:</source>
        <translation>Символ валюти:</translation>
    </message>
    <message>
        <source>Contact Information</source>
        <translation>Контактні дані</translation>
    </message>
    <message>
        <source>Data</source>
        <translation>Дані</translation>
    </message>
    <message>
        <source>Preview</source>
        <translation>Огляд</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Друк</translation>
    </message>
    <message>
        <source>Web Page (*.html *.htm)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>iCalendar (*.ics)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Outlook CSV (*.csv)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export Report</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>View Reports</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Create Report</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Phone: %1</source>
        <translation>Телефон: %1</translation>
    </message>
    <message>
        <source>Fax: %1</source>
        <translation>Факс: %1</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>Час</translation>
    </message>
    <message>
        <source>Subtotal</source>
        <translation>Проміжний підсумок</translation>
    </message>
    <message>
        <source>Taxes</source>
        <translation>Податки</translation>
    </message>
    <message>
        <source>Total</source>
        <translation>Загалом</translation>
    </message>
</context>
<context>
    <name>Session</name>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation>
            <numerusform>%n година</numerusform>
            <numerusform>%n години</numerusform>
            <numerusform>%n годин</numerusform>
        </translation>
    </message>
    <message>
        <source>%L1 hours</source>
        <translation>%L1 год.</translation>
    </message>
</context>
<context>
    <name>SessionDelegate</name>
    <message>
        <source>Error</source>
        <translation type="unfinished">Помилка</translation>
    </message>
    <message>
        <source>Session conflicts with other sessions.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SessionDialog</name>
    <message>
        <source>Add Session</source>
        <translation>Додати сеанс</translation>
    </message>
    <message>
        <source>Date:</source>
        <translation>Дата:</translation>
    </message>
    <message>
        <source>Start:</source>
        <translation>Початок:</translation>
    </message>
    <message>
        <source>Stop:</source>
        <translation>Зупинка:</translation>
    </message>
    <message>
        <source>Task:</source>
        <translation>Завдання:</translation>
    </message>
    <message>
        <source>Edit Session</source>
        <translation>Змінити сеанс</translation>
    </message>
</context>
<context>
    <name>SessionModel</name>
    <message>
        <source>Total</source>
        <translation type="unfinished">Загалом</translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start</source>
        <translation type="unfinished">Початок</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation type="unfinished">Зупинка</translation>
    </message>
    <message>
        <source>Task</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hours</source>
        <translation type="unfinished">Час</translation>
    </message>
    <message>
        <source>Daily</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Weekly</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Monthly</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Report</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>00:00:00</source>
        <translation>00:00:00</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Початок</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Зупинка</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Скасувати</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Project</source>
        <translation>&amp;Проект</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>&amp;Додати</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Вилучити</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>В&amp;ийти</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>&amp;Session</source>
        <translation>&amp;Сеанс</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>З&amp;міни</translation>
    </message>
    <message>
        <source>Ctrl+Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>S&amp;ettings</source>
        <translation>П&amp;араметри</translation>
    </message>
    <message>
        <source>Columns</source>
        <translation>Стовпчики</translation>
    </message>
    <message>
        <source>&amp;Decimal Totals</source>
        <translation>Д&amp;есятичний підсумок</translation>
    </message>
    <message>
        <source>&amp;Inline Editing</source>
        <translation>Редагування в &amp;один рядок</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>&amp;Мова програми...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Довідка</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Про програму</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Про &amp;Qt</translation>
    </message>
    <message>
        <source>Project</source>
        <translation>Проект</translation>
    </message>
    <message>
        <source>Timer</source>
        <translation>Таймер</translation>
    </message>
    <message>
        <source>Show all</source>
        <translation>Показати все</translation>
    </message>
    <message>
        <source>Show only unbilled</source>
        <translation>Показувати лише невідфактуровані</translation>
    </message>
    <message>
        <source>Show only this year</source>
        <translation>Показувати лише за цей рік</translation>
    </message>
    <message>
        <source>Show only this month</source>
        <translation>Показувати лише за цей місяць</translation>
    </message>
    <message>
        <source>Show only this week</source>
        <translation>Показувати лише за цей тиждень</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Session conflicts with other sessions.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Restore</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to read time data.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Без назви</translation>
    </message>
    <message>
        <source>Unable to write time data.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>There are timers running. Stop timers and quit?</source>
        <translation>Таймери працюють. Зупинити їх і вийти?</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Про</translation>
    </message>
    <message>
        <source>A program to help track spent time</source>
        <translation>Програма для відстежування витраченого часу</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Запитання</translation>
    </message>
    <message>
        <source>&amp;Create Report...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>View R&amp;eports</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel this session?</source>
        <translation>Скасувати цей сеанс?</translation>
    </message>
    <message>
        <source>Add Project</source>
        <translation>Додати проект</translation>
    </message>
    <message>
        <source>Enter project name:</source>
        <translation>Введіть назву проекту:</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Помилка</translation>
    </message>
    <message>
        <source>Unable to create time data location.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to move time data location.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A project with that name already exists.</source>
        <translation>Проект з такою назвою вже є.</translation>
    </message>
    <message>
        <source>Remove selected project?</source>
        <translation>Вилучити вибраний проект?</translation>
    </message>
    <message>
        <source>Remove selected session?</source>
        <translation>Вилучити вибраний сеанс?</translation>
    </message>
    <message numerus="yes">
        <source>%n timer(s) running</source>
        <translation>
            <numerusform>Працює %n таймер</numerusform>
            <numerusform>Працюють %n таймери</numerusform>
            <numerusform>Працюють %n таймерів</numerusform>
        </translation>
    </message>
    <message>
        <source>Kapow Punch Clock</source>
        <translation>Kapow Punch Clock</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Punch clock program</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Store settings as INI format in specified file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do not create automatic backups of time data.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The time data file to use.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
